;;;;;;;;;;;;;;;;;;;;;;;
; Variable definition ;
;;;;;;;;;;;;;;;;;;;;;;;

globals [
         ; INPUT SUBSIDIES 
         ;SCENARIO                  ; input subsidy scenario - access can be early, typical or late regarding time of year 
         exo-access                 ; true/ false whether there is access to exogenous inputs  
         ;EXO-FACTOR-M              ; access to inputs leads to an increase in time spent on maize by a factor 
         ;EXO-FACTOR-P              ; access to inputs leads to an increase in time spent on pigeon pea by a factor 
                    
         
         ; DROUGHT 
         ;P-DROUGHT                 ; likelihood of it being a drought year 
         random-drought             ; random number generated for drought 
         drought                    ; boolean drought is true/ false 
          
         ; TIME OF YEAR
         month                      ; the month of the year 
         
         ; VIEW                     
         VIEW                       ; view can be either agent-type, wealth-rating or food-adequacy                         
        ] 

            
breed [agents agent]                 ; an agent represents a household 

agents-own [
            ; AGENTS' TYPOLOGY 
            agent-type               ; either 1, 2, 3 or 4 depending upon HH gender and household wellbeing 
            
            ; AGENTS' CHARACTERISTICS 
            agent-id                 ; unique id of agent 
            agent-wealth-rating      ; wellbeing as a proxy of buy: sell ratio 
            agent-land-area          ; total area of land owned by the household in hectares
            agent-territory          ; patch corresponding to agent x,y coodinates 
            agent-livestock          ; number of livestock owned by household 
            agent-poultry            ; number of poultry owned by household 
            agent-food-adequacy      ; self-assessed food adequacy: 1 = less than adequate; 2 = just adequate; 3 = more than adequate 
          
           
            
            ; AGENTS' OPTIONS
            ; Thresholds between agents options based on the agent type 
            p-maize-type             ; spend time farming maize
            p-spotato-type           ; spend time farming sweet potato 
            p-rice-type              ; spend time farming rice 
            p-ppea-type              ; spend time farming pigeon pea 
            p-tobacco-type           ; spend time farming tobacco 
            p-cassava-type           ; spend time farming cassava 
            p-fishing-type           ; spend time fishing 
            p-hunting-type           ; spend time hunting 
            p-livestock-type         ; spend time tending to livestock 
            p-wildfood-type          ; spend time collecting wild foods and indeginous fruit 
            p-firewood-type          ; spend time collecting firewood 
            p-ganyu-type             ; invest time in casual labour (ganyu) 
            p-sell-type              ; sell at market 
            p-buy-type               ; buy from market 
                        
            
            ; Impact of input subsidies 
            ;P-EXO                   ; likelihood of having access to input subsidies 
            exo-random               ; chance of being selected 
            exo-access-agent         ; true/ false whether agent has access to inputs or not
           
            ; AGENTS' DECISIONS & ACTIONS 
            p-total-type             ; total time spent (calculated as the sum of all of the p-"activity"-type
            p-maize                  ; proportion of time spent on maize farming 
            p-spotato                ; proportion of time spent on sweet potato farming 
            p-rice
            p-ppea 
            p-tobacco 
            p-cassava 
            p-fishing
            p-hunting
            p-livestock
            p-wildfood
            p-firewood
            p-ganyu 
            p-sell 
            p-buy  
            ]

patches-own [          
             study-area             
             ] 


 
;;;;;;;;;;;;;;;;;;;;;;;;
; MODEL INITIALISATION ;
;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  clear-all
 
  ;FIELDS 
  define-fields                           ; provide patches with spatial characteristics 
  ;AGENTS 
  define-agents                           ; create and characterise each agent for the first time
  ; REPRESENTATION OF THE LANDSCAPE  
  update-view 
  reset-ticks                             ; sets up a particular view 
end 

;;;;;;;;;;;;;
; MODEL RUN ; 
;;;;;;;;;;;;;

to go 
  
  tick                                    ; a time step 
  ;MONTH 
  define-months                           ; defines the months based on time steps 
  ; DROUGHT? 
  drought-occ                             ; occurence of drought - yes/no 
  ; OPTIONS
  option-agent-type                       ; agent type probabilities
  
  ; EXOGENOUS IMPACT 
  exo-onset                               ; timing of the input subsidy programme
  exo-impact                              ; impact of access to imput subsidies on agent decisions 
  
  ;DECISIONS 
  decision-agent-type                     ; time-allocation decisions 
 
  ; WEALTH RATING 
  define-wealth                           ; calculates the wealth-rating at each time step
  
  ; FOOD ADEQUACY 
  define-food-adequacy                    ; updates food-adequacy value at each time step 
  
  ; UPDATE VIEW 
  update-view 
  
  
  if ticks = 121                          ; stops the simulation once it has run for 121 time steps (ten years)
  [
    stop 
  ]  
end  



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; INITIAL CONDITIONS & SUB-PROCESSSES ;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


; INPUT DATA


to define-fields 
  
  ; Reading external file to draw the study area 
  file-open "study-area.txt"
  foreach sort patches [ask ? [set study-area file-read] ]
  file-close
end
 
to define-agents 
  ; create and characterise agents
  create-agents 15808                      ; number of agents in the study area based on the file try_agent_id.txt
  ask agents [hide-turtle] 
  
  random-seed new-seed                     ; defines a different set of random numbers each time the model is run 
  
  ;Id: reading external file to define the ID of each agent 
  file-open "agent-id.txt"
  foreach sort agents [ask ? [set agent-id file-read] ]
  file-close
  
  ; Location: reading external file to define the coordinates of each agent
  file-open "x-cor.txt" 
  foreach sort agents [ask ? [set xcor file-read] ]
  file-close
  
  file-open "y-cor.txt" 
  foreach sort agents [ask ? [set ycor file-read] ]
  file-close
  
  ; Agent type: reading external file to define agent type. 
  file-open "agent-type.txt"
  foreach sort agents [ask ? [set agent-type file-read] ] 
  file-close
  
  ; Land owned: reading external file to define area of land owned (in hectares) 
  file-open "agent-land.txt"
  foreach sort agents [ask ? [set agent-land-area file-read] ] 
  file-close
  
  ; Livestock owned: reading external file to define number of livestock owned 
  file-open "agent-livestock.txt"
  foreach sort agents [ask ? [set agent-livestock file-read] ] 
  file-close
  
  ; Poultry owned: reading external file to define number of poultry owned 
  file-open "agent-poultry.txt"
  foreach sort agents [ask ? [set agent-poultry file-read] ] 
  file-close
  
  ; Food-adequacy: reading exernal file to define self-assesment of food-adequacy 
  file-open "agent-foodcons.txt"
  foreach sort agents [ask ? [set agent-food-adequacy file-read] ] 
  file-close
  
  ; Additional patch related characteristics 
  ask agents 
  [ 
    set agent-territory patch-here
  ] 
end 



;DIFFERENT ALTERNATIVES TO VIEW THE STUDY AREA

  
  to view-agent-type
    set VIEW "agent-type" 
    ask agents 
      [
       if agent-type = 1 [ask agent-territory [set pcolor blue]]
       if agent-type = 2 [ask agent-territory[set pcolor magenta]]
       if agent-type = 3 [ask agent-territory [set pcolor brown + 2]]
       if agent-type = 4 [ask agent-territory [set pcolor orange + 2]]
      ]   
  ask patches 
      [ 
       if study-area = 0      [set pcolor white]    ; No data 
       if pcolor = black [set pcolor white]         
      ]
  
  end
      
  to view-wealth-rating 
    set VIEW "wealth-rating"
  ask agents
  [ 
   if agent-wealth-rating < 0 [ask agent-territory [set pcolor blue - 2]] 
   if agent-wealth-rating = 0 [ask agent-territory [set pcolor blue + 2]]  
   if agent-wealth-rating > 0 [ask agent-territory [set pcolor blue + 4]]
  ] 
  
  ask patches 
      [ 
       if study-area = 0      [set pcolor white]    ; No data  
       if pcolor = black [set pcolor white]            
      ]
end 
  
  to view-food-adequacy
    set VIEW "food-adequacy"
     ask agents
  [ 
   if agent-food-adequacy <= 1 [ask agent-territory [set pcolor 35]] 
   if (agent-food-adequacy > 1) and (agent-food-adequacy <= 2) [ask agent-territory [set pcolor 55]]  
   if (agent-food-adequacy > 2) and (agent-food-adequacy <= 3) [ask agent-territory [set pcolor 65]]
  ] 
  
  ask patches 
      [ 
       if study-area = 0      [set pcolor white]    ; No data  
       if pcolor = black [set pcolor white]            
      ]
end 
    

;;;;;;;;;;
; MONTHS ; 
;;;;;;;;;;

to define-months 
  ; divide seasons into 12 months according to ticks 
  if (ticks  = 1) or (ticks = 13) or (ticks = 25) or (ticks = 37) or (ticks = 49) or (ticks = 61) or (ticks = 73) or (ticks = 85) or (ticks = 97) or (ticks = 109)       
  [ 
    set month "JANUARY" 
  ]
  if (ticks = 2) or (ticks = 14) or (ticks = 26) or (ticks = 38) or (ticks = 50) or (ticks = 62) or (ticks = 74) or (ticks = 86) or (ticks = 98) or (ticks = 110) 
  [ 
    set month "FEBRUARY" 
  ]
  if (ticks = 3) or (ticks = 15) or (ticks = 27) or (ticks = 39) or (ticks = 51) or (ticks = 63) or (ticks = 75) or (ticks = 87) or (ticks = 99) or (ticks = 111) 
  [ 
    set month "MARCH"
  ] 
  if (ticks = 4) or (ticks = 16) or (ticks = 28) or (ticks = 40) or (ticks = 52) or (ticks = 64) or (ticks = 76) or (ticks = 88) or (ticks = 100) or (ticks = 112) 
  [ 
    set month "APRIL" 
  ] 
  if (ticks = 5) or (ticks = 17) or (ticks = 29) or (ticks = 41) or (ticks = 53) or (ticks = 65) or (ticks = 77) or (ticks = 89) or (ticks = 101) or (ticks = 113) 
  [ 
    set month "MAY" 
  ] 
  if (ticks = 6) or (ticks = 18) or (ticks = 30) or (ticks = 42) or (ticks = 54) or (ticks = 66) or (ticks = 78) or (ticks = 90) or (ticks = 102) or (ticks = 114) 
  [ 
    set month "JUNE" 
  ] 
  if (ticks = 7) or (ticks = 19) or (ticks = 31) or (ticks = 43) or (ticks = 55) or (ticks = 67) or (ticks = 79) or (ticks = 91) or (ticks = 103) or (ticks = 115) 
  [ 
    set month "JULY" 
  ] 
  if (ticks = 8) or (ticks = 20) or (ticks = 32) or (ticks = 44) or (ticks = 56) or (ticks = 68) or (ticks = 80) or (ticks = 92) or (ticks = 104) or (ticks = 116) 
  [ 
    set month "AUGUST" 
  ] 
  if (ticks = 9) or (ticks = 21) or (ticks = 33) or (ticks = 45) or (ticks = 57) or (ticks = 69) or (ticks = 81) or (ticks = 93) or (ticks = 105) or (ticks = 117)  
  [ 
    set month "SEPTEMBER" 
  ] 
  if (ticks = 10) or (ticks = 22) or (ticks = 34) or (ticks = 46) or (ticks = 58) or (ticks = 70) or (ticks = 82) or (ticks = 94) or (ticks = 106) or (ticks = 118)  
  [ 
    set month "OCTOBER"
  ] 
  if (ticks = 11) or (ticks = 23) or (ticks = 35) or (ticks = 47) or (ticks = 59) or (ticks = 71) or (ticks = 83) or (ticks = 95) or (ticks = 107) or (ticks = 119) 
  [ 
    set month "NOVEMBER"
  ] 
  if (ticks = 12) or (ticks = 24) or (ticks = 36) or (ticks = 48) or (ticks = 60) or (ticks = 72) or (ticks = 84) or (ticks = 96) or (ticks = 108) or (ticks = 120) 
  [ 
    set month "DECEMBER" 
  ]
  
end 
  


  
;;;;;;;;;;;;;;;;;;;;;
; DROUGHT OCCURENCE ;
;;;;;;;;;;;;;;;;;;;;;

to drought-occ 
  ; whether it is a drought year or not 
  ifelse month ="JANUARY"
  [set random-drought random-float 1 
  ifelse (P-DROUGHT <= random-drought)
  [set drought FALSE] 
  [set drought TRUE] 
  ]
  [
    set drought drought
  ]
  
end 
  

 
;;;;;;;;;;;;;;;;;;  
; AGENTS OPTIONS ;
;;;;;;;;;;;;;;;;;;  
     
to-report log-normal[a b]
  ; reports log-normal distribution 
 
  ifelse (a > 0.0) and (b > 0.0) 
  [let c  ln ( 1 + (b ^ 2 / a ^ 2))
  let M  ln (a) - (c / 2)
  let S  sqrt c
  report exp (random-normal M S)] 
  [let p-act random-normal a b 
   set p-act p-act ^ 2 
   report sqrt p-act
  ]    
end    

to option-agent-type 
  ; assign time allocation probabilities for each month 
  
  ask agents 
  [  
      if drought = FALSE 
      [ 
        if agent-type = 1     ; Rich male HH 
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.12 0.04              
            set p-spotato-type log-normal 0.03 0.02         
            set p-rice-type log-normal 0.10 0.07           
            set p-ppea-type log-normal 0.03 0.03            
            set p-tobacco-type log-normal 0.0 0.01          
            set p-cassava-type log-normal 0.03 0.03          
            set p-fishing-type log-normal 0.06 0.06            
            set p-hunting-type log-normal 0.03 0.00          
            set p-livestock-type log-normal 0.11 0.05         
            set p-wildfood-type log-normal 0.06 0.04           
            set p-firewood-type log-normal 0.10 0.05         
            set p-ganyu-type log-normal 0.08 0.03            
            set p-sell-type log-normal 0.05 0.03              
            set p-buy-type log-normal 0.16 0.18
    
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.08 0.04             
            set p-spotato-type log-normal 0.03 0.02         
            set p-rice-type log-normal 0.09 0.07            
            set p-ppea-type log-normal 0.02 0.02              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.04 0.03           
            set p-fishing-type log-normal 0.06 0.06           
            set p-hunting-type log-normal 0.04 0.02           
            set p-livestock-type log-normal 0.10 0.05          
            set p-wildfood-type log-normal 0.07 0.04          
            set p-firewood-type log-normal 0.12 0.06          
            set p-ganyu-type log-normal 0.06 0.03             
            set p-sell-type log-normal 0.04 0.02              
            set p-buy-type log-normal 0.21 0.19
             
          ] 
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.07 0.01             
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.07 0.06             
            set p-ppea-type log-normal 0.01 0.02              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.04 0.04         
            set p-fishing-type log-normal 0.08 0.04     
            set p-hunting-type log-normal 0.05 0.03           
            set p-livestock-type log-normal 0.11 0.04          
            set p-wildfood-type log-normal 0.07 0.05           
            set p-firewood-type log-normal 0.12 0.04          
            set p-ganyu-type log-normal 0.08 0.06              
            set p-sell-type log-normal 0.04 0.02                 
            set p-buy-type log-normal 0.19 0.10
           
          ] 
          if month = "APRIL"
          [ 
            set p-maize-type log-normal 0.09 0.02               
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.07 0.06             
            set p-ppea-type log-normal 0.03 0.02              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.05 0.03            
            set p-fishing-type log-normal 0.08 0.04            
            set p-hunting-type log-normal 0.04 0.03            
            set p-livestock-type log-normal 0.12 0.04          
            set p-wildfood-type log-normal 0.06 0.04           
            set p-firewood-type log-normal 0.10 0.05         
            set p-ganyu-type log-normal 0.11 0.03             
            set p-sell-type log-normal 0.08 0.00               
            set p-buy-type log-normal 0.10 0.06 
              
          ] 
          if month = "MAY"  
          [ 
            set p-maize-type log-normal 0.09 0.04              
            set p-spotato-type log-normal 0.02 0.02          
            set p-rice-type log-normal 0.04 0.05            
            set p-ppea-type log-normal 0.03 0.03              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.05 0.03            
            set p-fishing-type log-normal 0.04 0.04            
            set p-hunting-type log-normal 0.05 0.03            
            set p-livestock-type log-normal 0.10 0.04         
            set p-wildfood-type log-normal 0.04 0.02           
            set p-firewood-type log-normal 0.10 0.04          
            set p-ganyu-type log-normal 0.10 0.03             
            set p-sell-type log-normal 0.13 0.04               
            set p-buy-type log-normal 0.17 0.11 
            
          ] 
          if month = "JUNE"
          [ 
            set p-maize-type log-normal 0.06 0.03               
            set p-spotato-type log-normal 0.03 0.02          
            set p-rice-type log-normal 0.09 0.07             
            set p-ppea-type log-normal 0.05 0.03              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.05 0.03            
            set p-fishing-type log-normal 0.03 0.03            
            set p-hunting-type log-normal 0.07 0.01           
            set p-livestock-type log-normal 0.09 0.06          
            set p-wildfood-type log-normal 0.05 0.01           
            set p-firewood-type log-normal 0.10 0.04          
            set p-ganyu-type log-normal 0.06 0.03             
            set p-sell-type log-normal 0.12 0.02               
            set p-buy-type log-normal 0.19 0.20 
            
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.09 0.06              
            set p-spotato-type log-normal 0.03 0.02          
            set p-rice-type log-normal 0.07 0.05              
            set p-ppea-type log-normal 0.06 0.05              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.06 0.06            
            set p-fishing-type log-normal 0.03 0.02            
            set p-hunting-type log-normal 0.09 0.03            
            set p-livestock-type log-normal 0.10 0.04           
            set p-wildfood-type log-normal 0.05 0.02           
            set p-firewood-type log-normal 0.11 0.04          
            set p-ganyu-type log-normal 0.06 0.03             
            set p-sell-type log-normal 0.12 0.02              
            set p-buy-type log-normal 0.10 0.03 
            
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.12 0.03              
            set p-spotato-type log-normal 0.02 0.01          
            set p-rice-type log-normal 0.04 0.04             
            set p-ppea-type log-normal 0.05 0.06              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.06 0.05            
            set p-fishing-type log-normal 0.05 0.03            
            set p-hunting-type log-normal 0.07 0.02            
            set p-livestock-type log-normal 0.10 0.05          
            set p-wildfood-type log-normal 0.04 0.02           
            set p-firewood-type log-normal 0.10 0.05          
            set p-ganyu-type log-normal 0.08 0.04            
            set p-sell-type log-normal 0.10 0.04               
            set p-buy-type log-normal 0.12 0.08 
             
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.12 0.04              
            set p-spotato-type log-normal 0.01 0.02         
            set p-rice-type log-normal 0.03 0.03             
            set p-ppea-type log-normal 0.02 0.03              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.07 0.04            
            set p-fishing-type log-normal 0.07 0.02            
            set p-hunting-type log-normal 0.08 0.03            
            set p-livestock-type log-normal 0.12 0.04         
            set p-wildfood-type log-normal 0.06 0.05           
            set p-firewood-type log-normal 0.11 0.05          
            set p-ganyu-type log-normal 0.11 0.04             
            set p-sell-type log-normal 0.09 0.03               
            set p-buy-type log-normal 0.08 0.03 
              
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.15 0.05               
            set p-spotato-type log-normal 0.01 0.01          
            set p-rice-type log-normal 0.03 0.04             
            set p-ppea-type log-normal 0.00 0.01              
            set p-tobacco-type log-normal 0.01 0.01           
            set p-cassava-type log-normal 0.06 0.04            
            set p-fishing-type log-normal 0.07 0.05            
            set p-hunting-type log-normal 0.07 0.05            
            set p-livestock-type log-normal 0.11 0.03          
            set p-wildfood-type log-normal 0.06 0.04           
            set p-firewood-type log-normal 0.10 0.07           
            set p-ganyu-type log-normal 0.10 0.01            
            set p-sell-type log-normal 0.08 0.02                
            set p-buy-type log-normal 0.10 0.06 
           
          ] 
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.13 0.06              
            set p-spotato-type log-normal 0.02 0.02          
            set p-rice-type log-normal 0.04 0.03             
            set p-ppea-type log-normal 0.02 0.02              
            set p-tobacco-type log-normal 0.01 0.01           
            set p-cassava-type log-normal 0.06 0.03            
            set p-fishing-type log-normal 0.06 0.04            
            set p-hunting-type log-normal 0.07 0.03            
            set p-livestock-type log-normal 0.09 0.03           
            set p-wildfood-type log-normal 0.08 0.04           
            set p-firewood-type log-normal 0.10 0.06          
            set p-ganyu-type log-normal 0.09 0.05             
            set p-sell-type log-normal 0.06 0.03               
            set p-buy-type log-normal 0.14 0.11
               
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.16 0.03              
            set p-spotato-type log-normal 0.02 0.02          
            set p-rice-type log-normal 0.05 0.04             
            set p-ppea-type log-normal 0.03 0.03              
            set p-tobacco-type log-normal 0.01 0.02           
            set p-cassava-type log-normal 0.07 0.02            
            set p-fishing-type log-normal 0.05 0.06            
            set p-hunting-type log-normal 0.02 0.02           
            set p-livestock-type log-normal 0.12 0.04          
            set p-wildfood-type log-normal 0.08 0.03          
            set p-firewood-type log-normal 0.08 0.04         
            set p-ganyu-type log-normal 0.11 0.02             
            set p-sell-type log-normal 0.04 0.03               
            set p-buy-type log-normal 0.11 0.05 
           
          ] 
        ]
        if agent-type = 2       ; poor male HH
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.10 0.06               
            set p-spotato-type log-normal 0.05 0.03          
            set p-rice-type log-normal 0.08 0.07            
            set p-ppea-type log-normal 0.04 0.04             
            set p-tobacco-type log-normal 0.05 0.05          
            set p-cassava-type log-normal 0.07 0.03          
            set p-fishing-type log-normal 0.07 0.04           
            set p-hunting-type log-normal 0.04 0.03           
            set p-livestock-type log-normal 0.07 0.02         
            set p-wildfood-type log-normal 0.06 0.05           
            set p-firewood-type log-normal 0.07 0.03          
            set p-ganyu-type log-normal 0.07 0.03              
            set p-sell-type log-normal 0.05 0.02                
            set p-buy-type log-normal 0.15 0.09  
             
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.11 0.06            
            set p-spotato-type log-normal 0.03 0.02          
            set p-rice-type log-normal 0.08 0.06             
            set p-ppea-type log-normal 0.02 0.02              
            set p-tobacco-type log-normal 0.06 0.04           
            set p-cassava-type log-normal 0.07 0.02           
            set p-fishing-type log-normal 0.09 0.03           
            set p-hunting-type log-normal 0.03 0.04           
            set p-livestock-type log-normal 0.08 0.02          
            set p-wildfood-type log-normal 0.07 0.02           
            set p-firewood-type log-normal 0.06 0.02          
            set p-ganyu-type log-normal 0.09 0.03             
            set p-sell-type log-normal 0.05 0.03               
            set p-buy-type log-normal 0.11 0.06 
            
          ] 
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.08 0.05              
            set p-spotato-type log-normal 0.05 0.04          
            set p-rice-type log-normal 0.05 0.04             
            set p-ppea-type log-normal 0.02 0.02              
            set p-tobacco-type log-normal 0.07 0.05           
            set p-cassava-type log-normal 0.05 0.02            
            set p-fishing-type  log-normal 0.07 0.02            
            set p-hunting-type log-normal 0.06 0.03            
            set p-livestock-type log-normal 0.07 0.02          
            set p-wildfood-type log-normal 0.06 0.03           
            set p-firewood-type log-normal 0.07 0.02          
            set p-ganyu-type log-normal 0.06 0.03 
            set p-sell-type log-normal 0.10 0.07               
            set p-buy-type log-normal 0.16 0.12 
              
          ] 
          if month = "APRIL"
          [ 
            set p-maize-type log-normal 0.09 0.01               
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.05 0.05             
            set p-ppea-type log-normal 0.02 0.02             
            set p-tobacco-type log-normal 0.05 0.04           
            set p-cassava-type log-normal 0.05 0.02            
            set p-fishing-type log-normal 0.05 0.03            
            set p-hunting-type log-normal 0.04 0.02           
            set p-livestock-type log-normal 0.08 0.03          
            set p-wildfood-type log-normal 0.05 0.01           
            set p-firewood-type log-normal 0.09 0.02           
            set p-ganyu-type log-normal 0.06 0.04             
            set p-sell-type log-normal 0.16 0.06              
            set p-buy-type log-normal 0.14 0.05 
            
          ] 
          if month = "MAY"  
          [ 
            set p-maize-type log-normal 0.06 0.03              
            set p-spotato-type log-normal 0.04 0.03          
            set p-rice-type log-normal 0.06 0.05             
            set p-ppea-type log-normal 0.03 0.03              
            set p-tobacco-type log-normal 0.04 0.04           
            set p-cassava-type log-normal 0.06 0.01            
            set p-fishing-type log-normal 0.04 0.01            
            set p-hunting-type log-normal 0.04 0.03           
            set p-livestock-type log-normal 0.07 0.03          
            set p-wildfood-type log-normal 0.05 0.04          
            set p-firewood-type log-normal 0.09 0.04          
            set p-ganyu-type log-normal 0.07 0.03             
            set p-sell-type log-normal 0.17 0.12               
            set p-buy-type log-normal 0.16 0.06 
              
          ] 
          if month = "JUNE"
          [ 
            set p-maize-type log-normal 0.05 0.02              
            set p-spotato-type log-normal 0.02 0.03          
            set p-rice-type log-normal 0.07 0.05             
            set p-ppea-type log-normal 0.05 0.03              
            set p-tobacco-type log-normal 0.02 0.03           
            set p-cassava-type log-normal 0.07 0.01            
            set p-fishing-type log-normal 0.03 0.02            
            set p-hunting-type log-normal 0.06 0.04            
            set p-livestock-type log-normal 0.08 0.04          
            set p-wildfood-type log-normal 0.05 0.04           
            set p-firewood-type log-normal 0.10 0.03          
            set p-ganyu-type log-normal 0.07 0.04             
            set p-sell-type log-normal 0.12 0.06               
            set p-buy-type log-normal 0.17 0.09 
            
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.07 0.03              
            set p-spotato-type log-normal 0.03 0.04          
            set p-rice-type log-normal 0.08 0.06             
            set p-ppea-type log-normal 0.07 0.05              
            set p-tobacco-type log-normal 0.02 0.02           
            set p-cassava-type log-normal 0.07 0.01            
            set p-fishing-type log-normal 0.04 0.03           
            set p-hunting-type log-normal 0.06 0.03            
            set p-livestock-type log-normal 0.09 0.03           
            set p-wildfood-type log-normal 0.05 0.03          
            set p-firewood-type log-normal 0.09 0.02          
            set p-ganyu-type log-normal 0.08 0.01             
            set p-sell-type log-normal 0.13 0.05               
            set p-buy-type log-normal 0.11 0.10
             
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.08 0.03               
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.07 0.05             
            set p-ppea-type log-normal 0.03 0.04              
            set p-tobacco-type log-normal 0.05 0.05           
            set p-cassava-type log-normal 0.08 0.01           
            set p-fishing-type log-normal 0.05 0.02            
            set p-hunting-type log-normal 0.04 0.03            
            set p-livestock-type log-normal 0.08 0.05        
            set p-wildfood-type log-normal 0.04 0.03          
            set p-firewood-type log-normal 0.09 0.02          
            set p-ganyu-type log-normal 0.05 0.03           
            set p-sell-type log-normal 0.09 0.02              
            set p-buy-type log-normal 0.18  0.12 
             
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.07 0.03              
            set p-spotato-type log-normal 0.04 0.04         
            set p-rice-type log-normal 0.05 0.04              
            set p-ppea-type log-normal 0.02 0.02             
            set p-tobacco-type log-normal 0.05 0.06          
            set p-cassava-type log-normal 0.07 0.02            
            set p-fishing-type log-normal 0.05 0.03            
            set p-hunting-type log-normal 0.04 0.02            
            set p-livestock-type log-normal 0.08 0.04         
            set p-wildfood-type log-normal 0.02 0.02          
            set p-firewood-type log-normal 0.09 0.02         
            set p-ganyu-type log-normal 0.05 0.03             
            set p-sell-type log-normal 0.09 0.03               
            set p-buy-type log-normal 0.23 0.16
           
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.11 0.03             
            set p-spotato-type log-normal 0.01 0.01         
            set p-rice-type log-normal 0.06 0.04             
            set p-ppea-type log-normal 0.02 0.02               
            set p-tobacco-type log-normal 0.06 0.04         
            set p-cassava-type log-normal 0.04 0.03          
            set p-fishing-type log-normal 0.07 0.04            
            set p-hunting-type log-normal 0.05 0.03            
            set p-livestock-type log-normal 0.07 0.03          
            set p-wildfood-type log-normal 0.07 0.02         
            set p-firewood-type log-normal 0.09 0.03         
            set p-ganyu-type log-normal 0.08 0.04          
            set p-sell-type log-normal 0.08 0.05               
            set p-buy-type log-normal 0.15 0.13 
            
          ] 
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.14 0.05              
            set p-spotato-type log-normal 0.03 0.04           
            set p-rice-type log-normal 0.06 0.06             
            set p-ppea-type log-normal 0.01 0.01              
            set p-tobacco-type log-normal 0.05 0.04            
            set p-cassava-type log-normal 0.06 0.03            
            set p-fishing-type log-normal 0.05 0.04            
            set p-hunting-type log-normal 0.03 0.03            
            set p-livestock-type log-normal 0.07 0.01         
            set p-wildfood-type log-normal 0.05 0.03          
            set p-firewood-type log-normal 0.07 0.02         
            set p-ganyu-type log-normal 0.09 0.03            
            set p-sell-type log-normal 0.06 0.04               
            set p-buy-type log-normal 0.19 0.18 
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.12 0.08               
            set p-spotato-type log-normal 0.04 0.04          
            set p-rice-type log-normal 0.06 0.05            
            set p-ppea-type log-normal 0.05 0.03            
            set p-tobacco-type log-normal 0.06 0.04           
            set p-cassava-type log-normal 0.07 0.02          
            set p-fishing-type log-normal 0.06 0.01          
            set p-hunting-type log-normal 0.02 0.00           
            set p-livestock-type log-normal 0.06 0.03          
            set p-wildfood-type log-normal 0.07 0.01           
            set p-firewood-type log-normal 0.06 0.03         
            set p-ganyu-type log-normal 0.07 0.01             
            set p-sell-type log-normal 0.05 0.03              
            set p-buy-type log-normal 0.18 0.20 
             
          ] 
        ]
        if agent-type = 3     ; Rich female HH 
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.12 0.03             
            set p-spotato-type log-normal 0.04 0.03         
            set p-rice-type log-normal 0.07 0.06           
            set p-ppea-type log-normal 0.04 0.02            
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.08 0.07          
            set p-fishing-type log-normal 0.07 0.05          
            set p-hunting-type log-normal 0.03 0.04          
            set p-livestock-type log-normal 0.09 0.02         
            set p-wildfood-type log-normal 0.07 0.04           
            set p-firewood-type log-normal 0.09 0.02          
            set p-ganyu-type log-normal 0.11 0.04            
            set p-sell-type log-normal 0.08 0.05              
            set p-buy-type log-normal 0.08 0.04 
            
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.10 0.05            
            set p-spotato-type log-normal 0.05 0.04        
            set p-rice-type log-normal 0.08 0.06             
            set p-ppea-type log-normal 0.03 0.02              
            set p-tobacco-type log-normal 0.01 0.01           
            set p-cassava-type log-normal 0.04 0.04          
            set p-fishing-type log-normal 0.06 0.04         
            set p-hunting-type log-normal 0.02 0.02         
            set p-livestock-type log-normal 0.10 0.02         
            set p-wildfood-type log-normal 0.07 0.03          
            set p-firewood-type log-normal 0.10 0.02         
            set p-ganyu-type log-normal 0.09 0.04            
            set p-sell-type log-normal 0.06 0.03               
            set p-buy-type log-normal 0.13 0.09 
            
          ] 
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.06 0.04              
            set p-spotato-type log-normal 0.05 0.05         
            set p-rice-type log-normal 0.07 0.05            
            set p-ppea-type log-normal 0.03 0.01              
            set p-tobacco-type log-normal 0.01 0.02         
            set p-cassava-type log-normal 0.06 0.04          
            set p-fishing-type log-normal 0.08 0.05           
            set p-hunting-type log-normal 0.04 0.03          
            set p-livestock-type log-normal 0.09 0.04          
            set p-wildfood-type log-normal 0.04 0.03          
            set p-firewood-type log-normal 0.11 0.01         
            set p-ganyu-type log-normal 0.08 0.05            
            set p-sell-type log-normal  0.04 0.02             
            set p-buy-type log-normal 0.18 0.07 
           
          ] 
          if month = "APRIL"
          [ 
            set p-maize-type log-normal 0.10 0.06              
            set p-spotato-type log-normal 0.05 0.03          
            set p-rice-type log-normal 0.03 0.04             
            set p-ppea-type log-normal 0.02 0.01              
            set p-tobacco-type log-normal 0.01 0.02           
            set p-cassava-type log-normal 0.06 0.02           
            set p-fishing-type log-normal 0.06 0.03           
            set p-hunting-type log-normal 0.04 0.02           
            set p-livestock-type log-normal 0.10 0.02           
            set p-wildfood-type log-normal 0.05 0.04          
            set p-firewood-type log-normal 0.10 0.03         
            set p-ganyu-type log-normal 0.09 0.01            
            set p-sell-type log-normal 0.08 0.04              
            set p-buy-type log-normal 0.18 0.03 
           
          ] 
          if month = "MAY"  
          [ 
            set p-maize-type log-normal 0.12 0.06               
            set p-spotato-type log-normal 0.04 0.03        
            set p-rice-type log-normal 0.09 0.06             
            set p-ppea-type log-normal 0.04 0.02              
            set p-tobacco-type log-normal 0.02 0.03           
            set p-cassava-type log-normal 0.05 0.04           
            set p-fishing-type log-normal 0.03 0.02           
            set p-hunting-type log-normal 0.03 0.01           
            set p-livestock-type log-normal 0.09 0.02          
            set p-wildfood-type log-normal 0.05 0.05         
            set p-firewood-type log-normal 0.13 0.03          
            set p-ganyu-type log-normal 0.10 0.04           
            set p-sell-type log-normal 0.13 0.03              
            set p-buy-type log-normal 0.05 0.03 
              
          ] 
          if month = "JUNE"
          [ 
            set p-maize-type log-normal 0.07 0.04 
            set p-spotato-type log-normal 0.04 0.03          
            set p-rice-type log-normal 0.09 0.06             
            set p-ppea-type log-normal 0.06 0.03             
            set p-tobacco-type log-normal 0.01 0.02          
            set p-cassava-type log-normal 0.05 0.04          
            set p-fishing-type log-normal 0.03 0.02           
            set p-hunting-type log-normal 0.03 0.02           
            set p-livestock-type log-normal 0.10 0.03        
            set p-wildfood-type log-normal  0.03 0.01         
            set p-firewood-type log-normal  0.15 0.04        
            set p-ganyu-type log-normal 0.07 0.05           
            set p-sell-type log-normal 0.10 0.04             
            set p-buy-type log-normal 0.12 0.09 
            
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.11 0.05              
            set p-spotato-type log-normal 0.02 0.01         
            set p-rice-type log-normal 0.07 0.06           
            set p-ppea-type log-normal 0.06 0.04             
            set p-tobacco-type log-normal 0.01 0.01          
            set p-cassava-type log-normal 0.05 0.04           
            set p-fishing-type log-normal 0.03 0.02           
            set p-hunting-type log-normal 0.02 0.01           
            set p-livestock-type log-normal 0.08 0.02         
            set p-wildfood-type log-normal  0.04 0.02         
            set p-firewood-type log-normal 0.13 0.03        
            set p-ganyu-type log-normal 0.08 0.07           
            set p-sell-type log-normal 0.11 0.07             
            set p-buy-type log-normal 0.14 0.10 
              
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.10 0.05                
            set p-spotato-type log-normal 0.03 0.02         
            set p-rice-type log-normal 0.03 0.03           
            set p-ppea-type log-normal 0.05 0.03             
            set p-tobacco-type log-normal 0.02 0.03           
            set p-cassava-type log-normal 0.07 0.03           
            set p-fishing-type log-normal 0.07 0.03          
            set p-hunting-type log-normal 0.04 0.01          
            set p-livestock-type log-normal 0.08 0.06          
            set p-wildfood-type log-normal 0.03 0.02         
            set p-firewood-type log-normal  0.13 0.02        
            set p-ganyu-type log-normal 0.08 0.04            
            set p-sell-type log-normal 0.11 0.07              
            set p-buy-type log-normal 0.14 0.05 
            
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.12 0.02              
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.04 0.05            
            set p-ppea-type log-normal 0.02 0.00             
            set p-tobacco-type log-normal 0.02 0.02         
            set p-cassava-type log-normal 0.08 0.01           
            set p-fishing-type log-normal 0.08 0.03           
            set p-hunting-type log-normal 0.03 0.00           
            set p-livestock-type log-normal 0.11 0.04           
            set p-wildfood-type log-normal 0.03 0.01          
            set p-firewood-type log-normal 0.11 0.01       
            set p-ganyu-type log-normal 0.07 0.01            
            set p-sell-type log-normal  0.07 0.07             
            set p-buy-type log-normal 0.17 0.05 
             
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.11 0.05              
            set p-spotato-type log-normal 0.02 0.01          
            set p-rice-type log-normal 0.04 0.04            
            set p-ppea-type log-normal 0.02 0.01            
            set p-tobacco-type log-normal 0.02 0.02           
            set p-cassava-type log-normal 0.08 0.02           
            set p-fishing-type log-normal 0.07 0.03           
            set p-hunting-type log-normal 0.03 0.01          
            set p-livestock-type log-normal 0.11 0.05          
            set p-wildfood-type log-normal 0.02 0.01          
            set p-firewood-type log-normal 0.07 0.04         
            set p-ganyu-type log-normal 0.07 0.03            
            set p-sell-type log-normal 0.03 0.02              
            set p-buy-type log-normal 0.26 0.09 
           
          ] 
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.11 0.05               
            set p-spotato-type log-normal 0.02 0.01         
            set p-rice-type log-normal 0.04 0.04           
            set p-ppea-type log-normal 0.02 0.01           
            set p-tobacco-type log-normal 0.02 0.02           
            set p-cassava-type log-normal 0.08 0.02           
            set p-fishing-type log-normal 0.07 0.03          
            set p-hunting-type log-normal 0.03 0.01           
            set p-livestock-type log-normal 0.11 0.05          
            set p-wildfood-type log-normal 0.02 0.01         
            set p-firewood-type log-normal 0.07 0.04         
            set p-ganyu-type log-normal 0.07 0.03            
            set p-sell-type log-normal 0.03 0.02              
            set p-buy-type log-normal 0.26 0.09 
        
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.17 0.02            
            set p-spotato-type log-normal 0.03 0.02          
            set p-rice-type log-normal 0.09 0.07           
            set p-ppea-type log-normal 0.03 0.02             
            set p-tobacco-type log-normal 0.02 0.02        
            set p-cassava-type log-normal 0.07 0.04          
            set p-fishing-type log-normal 0.10 0.02           
            set p-hunting-type log-normal 0.03 0.02           
            set p-livestock-type log-normal 0.11 0.05           
            set p-wildfood-type log-normal 0.07 0.02        
            set p-firewood-type log-normal 0.06 0.02         
            set p-ganyu-type log-normal 0.09 0.03             
            set p-sell-type log-normal 0.04 0.04              
            set p-buy-type log-normal 0.14 0.08 
             
          ] 
        ]
        if agent-type = 4       ; poor female HH
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.07 0.04              
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.05 0.05           
            set p-ppea-type log-normal 0.03 0.02             
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.03 0.02         
            set p-fishing-type log-normal 0.07 0.03           
            set p-hunting-type log-normal 0.01 0.02        
            set p-livestock-type log-normal 0.11 0.07          
            set p-wildfood-type log-normal 0.07 0.04          
            set p-firewood-type log-normal 0.14 0.06          
            set p-ganyu-type log-normal 0.10 0.02            
            set p-sell-type log-normal 0.06 0.03               
            set p-buy-type log-normal 0.18 0.08 
            
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.03 0.03            
            set p-spotato-type log-normal 0.02 0.02        
            set p-rice-type log-normal 0.03 0.05            
            set p-ppea-type log-normal 0.01 0.01            
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.04 0.04         
            set p-fishing-type log-normal 0.06 0.03          
            set p-hunting-type log-normal 0.02 0.04         
            set p-livestock-type log-normal 0.12 0.05           
            set p-wildfood-type log-normal 0.10 0.02         
            set p-firewood-type log-normal 0.14 0.05        
            set p-ganyu-type log-normal 0.11 0.03           
            set p-sell-type log-normal 0.09 0.03             
            set p-buy-type log-normal 0.17 0.07 
            
          ] 
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.05 0.03               
            set p-spotato-type log-normal 0.03 0.02       
            set p-rice-type log-normal 0.04 0.04            
            set p-ppea-type log-normal 0.01 0.01             
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.03 0.04          
            set p-fishing-type log-normal 0.08 0.02          
            set p-hunting-type log-normal 0.02 0.04          
            set p-livestock-type log-normal 0.12 0.05          
            set p-wildfood-type log-normal 0.09 0.03           
            set p-firewood-type log-normal 0.14 0.05        
            set p-ganyu-type log-normal 0.10 0.07          
            set p-sell-type log-normal  0.10 0.02            
            set p-buy-type log-normal 0.14 0.12 
           
          ] 
          if month = "APRIL"
          [ 
            set p-maize-type log-normal 0.09 0.07              
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.05 0.06            
            set p-ppea-type log-normal 0.01 0.02             
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.03 0.04           
            set p-fishing-type log-normal 0.09 0.04           
            set p-hunting-type log-normal 0.03 0.04           
            set p-livestock-type log-normal 0.12 0.05       
            set p-wildfood-type log-normal 0.08 0.02         
            set p-firewood-type log-normal 0.14 0.05         
            set p-ganyu-type log-normal 0.12 0.03             
            set p-sell-type log-normal 0.08 0.04               
            set p-buy-type log-normal 0.09 0.04 
            
          ] 
          if month = "MAY"  
          [ 
            set p-maize-type log-normal 0.07 0.04              
            set p-spotato-type log-normal 0.02 0.02         
            set p-rice-type log-normal 0.05 0.06            
            set p-ppea-type log-normal 0.01 0.02              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.05 0.04           
            set p-fishing-type log-normal 0.07 0.05          
            set p-hunting-type log-normal 0.06 0.10          
            set p-livestock-type log-normal 0.12 0.04          
            set p-wildfood-type log-normal 0.07 0.02          
            set p-firewood-type log-normal 0.14 0.04          
            set p-ganyu-type log-normal 0.14 0.10            
            set p-sell-type log-normal 0.09 0.03              
            set p-buy-type log-normal 0.07 0.03 
             
          ] 
          if month = "JUNE"
          [ 
            set p-maize-type log-normal 0.07 0.02           
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.08 0.08            
            set p-ppea-type log-normal 0.03 0.04           
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.03 0.03           
            set p-fishing-type log-normal 0.05 0.05          
            set p-hunting-type log-normal 0.03 0.04           
            set p-livestock-type log-normal 0.13 0.05          
            set p-wildfood-type log-normal  0.06 0.04        
            set p-firewood-type log-normal  0.14 0.05        
            set p-ganyu-type log-normal 0.13 0.08          
            set p-sell-type log-normal 0.09 0.04            
            set p-buy-type log-normal 0.12 0.13 
           
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.05 0.03             
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.06 0.06            
            set p-ppea-type log-normal 0.03 0.04             
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.04 0.04           
            set p-fishing-type log-normal 0.06 0.07         
            set p-hunting-type log-normal 0.03 0.04         
            set p-livestock-type log-normal 0.12 0.05          
            set p-wildfood-type log-normal 0.05 0.03          
            set p-firewood-type log-normal 0.15 0.05          
            set p-ganyu-type log-normal 0.15 0.08            
            set p-sell-type log-normal 0.09 0.03             
            set p-buy-type log-normal 0.12 0.10 
            
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.08 0.05              
            set p-spotato-type log-normal 0.04 0.03         
            set p-rice-type log-normal 0.04 0.04           
            set p-ppea-type log-normal 0.02 0.03            
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.04 0.04           
            set p-fishing-type log-normal 0.08 0.05          
            set p-hunting-type log-normal 0.03 0.04           
            set p-livestock-type log-normal 0.12 0.05        
            set p-wildfood-type log-normal 0.04 0.02          
            set p-firewood-type log-normal 0.15 0.05        
            set p-ganyu-type log-normal 0.15 0.09            
            set p-sell-type log-normal 0.08 0.03              
            set p-buy-type log-normal 0.09 0.07 
          
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.06 0.03              
            set p-spotato-type log-normal 0.02 0.02         
            set p-rice-type log-normal 0.04 0.04          
            set p-ppea-type log-normal 0.02 0.03             
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.04 0.04          
            set p-fishing-type log-normal 0.07 0.03          
            set p-hunting-type log-normal 0.04 0.05           
            set p-livestock-type log-normal 0.12 0.04         
            set p-wildfood-type log-normal 0.05 0.03         
            set p-firewood-type log-normal 0.15 0.04        
            set p-ganyu-type log-normal 0.15 0.09            
            set p-sell-type log-normal 0.09 0.01              
            set p-buy-type log-normal 0.12 0.06 
            
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.07 0.03              
            set p-spotato-type log-normal 0.03 0.02          
            set p-rice-type log-normal 0.05 0.06            
            set p-ppea-type log-normal 0.01 0.03             
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.03 0.03           
            set p-fishing-type log-normal 0.08 0.02           
            set p-hunting-type log-normal 0.03 0.03           
            set p-livestock-type log-normal 0.13 0.05        
            set p-wildfood-type log-normal 0.05 0.01         
            set p-firewood-type log-normal 0.13 0.07        
            set p-ganyu-type log-normal 0.13 0.07            
            set p-sell-type log-normal 0.06 0.02             
            set p-buy-type log-normal 0.19 0.10 
            
          ] 
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.08 0.05             
            set p-spotato-type log-normal 0.02 0.01         
            set p-rice-type log-normal 0.05 0.06           
            set p-ppea-type log-normal 0.02 0.03            
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.05 0.04          
            set p-fishing-type log-normal 0.07 0.03          
            set p-hunting-type log-normal 0.02 0.02          
            set p-livestock-type log-normal 0.11 0.04         
            set p-wildfood-type log-normal 0.07 0.01        
            set p-firewood-type log-normal 0.13 0.05        
            set p-ganyu-type log-normal 0.12 0.05           
            set p-sell-type log-normal 0.06 0.03             
            set p-buy-type log-normal 0.17 0.08 
            
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.09 0.05             
            set p-spotato-type log-normal 0.03 0.02         
            set p-rice-type log-normal 0.05 0.07            
            set p-ppea-type log-normal 0.02 0.02             
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.03 0.03          
            set p-fishing-type log-normal 0.07 0.05          
            set p-hunting-type log-normal 0.01 0.02          
            set p-livestock-type log-normal 0.12 0.06         
            set p-wildfood-type log-normal 0.06 0.04        
            set p-firewood-type log-normal 0.13 0.04        
            set p-ganyu-type log-normal 0.10 0.05           
            set p-sell-type log-normal 0.05 0.02             
            set p-buy-type log-normal 0.19 0.17 
             
          ] 
        ]
      ]
      if drought = TRUE 
      [ 
        if agent-type = 1
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.06 0.03              
            set p-spotato-type log-normal 0.01 0.02        
            set p-rice-type log-normal 0.05 0.06            
            set p-ppea-type log-normal 0.02 0.01            
            set p-tobacco-type log-normal 0.00 0.01       
            set p-cassava-type log-normal 0.05 0.03       
            set p-fishing-type log-normal 0.05 0.03       
            set p-hunting-type log-normal 0.05 0.04        
            set p-livestock-type log-normal 0.10 0.03         
            set p-wildfood-type log-normal 0.05 0.01            
            set p-firewood-type log-normal 0.11 0.05           
            set p-ganyu-type log-normal 0.07 0.04           
            set p-sell-type log-normal 0.04 0.05            
            set p-buy-type log-normal 0.32 0.18 
          
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.04 0.02              
            set p-spotato-type log-normal 0.02 0.02          
            set p-rice-type log-normal 0.04 0.05            
            set p-ppea-type log-normal 0.01 0.01              
            set p-tobacco-type log-normal 0.04 0.01           
            set p-cassava-type log-normal 0.06 0.04          
            set p-fishing-type log-normal 0.05 0.04        
            set p-hunting-type log-normal 0.10 0.03         
            set p-livestock-type log-normal 0.02 0.00        
            set p-wildfood-type log-normal 0.11 0.05         
            set p-firewood-type log-normal 0.07 0.05        
            set p-ganyu-type log-normal 0.07 0.05          
            set p-sell-type log-normal 0.38 0.15             
          
          ] 
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.04 0.03            
            set p-spotato-type log-normal 0.02 0.03         
            set p-rice-type log-normal 0.02 0.01           
            set p-ppea-type log-normal 0.01 0.01           
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.05 0.02         
            set p-fishing-type log-normal 0.07 0.05          
            set p-hunting-type log-normal 0.04 0.03          
            set p-livestock-type log-normal 0.09 0.04       
            set p-wildfood-type log-normal 0.02 0.01        
            set p-firewood-type log-normal 0.10 0.05         
            set p-ganyu-type log-normal 0.07 0.07           
            set p-sell-type log-normal 0.14 0.16             
            set p-buy-type log-normal 0.31 0.16 
            
          ] 
          if month = "APRIL"
          [ 
            set p-maize-type log-normal 0.03 0.02            
            set p-spotato-type log-normal 0.02 0.02       
            set p-rice-type log-normal 0.03 0.05           
            set p-ppea-type log-normal 0.01 0.01           
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.04 0.03        
            set p-fishing-type log-normal 0.05 0.03        
            set p-hunting-type log-normal 0.04 0.04          
            set p-livestock-type log-normal 0.10 0.06         
            set p-wildfood-type log-normal 0.03 0.02          
            set p-firewood-type log-normal 0.11 0.04          
            set p-ganyu-type log-normal 0.08 0.09            
            set p-sell-type log-normal 0.14 0.17              
            set p-buy-type log-normal 0.30 0.15 
            
          ] 
          if month = "MAY"  
          [ 
            set p-maize-type log-normal 0.03 0.02           
            set p-spotato-type log-normal 0.02 0.02         
            set p-rice-type log-normal 0.04 0.06         
            set p-ppea-type log-normal 0.02 0.01            
            set p-tobacco-type log-normal 0.00 0.01        
            set p-cassava-type log-normal 0.04 0.02          
            set p-fishing-type log-normal 0.03 0.02         
            set p-hunting-type log-normal 0.03 0.03          
            set p-livestock-type log-normal 0.09 0.06         
            set p-wildfood-type log-normal 0.03 0.01         
            set p-firewood-type log-normal 0.11 0.04       
            set p-ganyu-type log-normal 0.08 0.07          
            set p-sell-type log-normal 0.07 0.04            
            set p-buy-type log-normal 0.40 0.24 
            
          ] 
          if month = "JUNE"
          [ 
            set p-maize-type log-normal 0.03 0.02            
            set p-spotato-type log-normal 0.02 0.02          
            set p-rice-type log-normal 0.05 0.06           
            set p-ppea-type log-normal 0.03 0.04             
            set p-tobacco-type log-normal 0.00 0.01        
            set p-cassava-type log-normal 0.05 0.02           
            set p-fishing-type log-normal 0.02 0.02           
            set p-hunting-type log-normal 0.04 0.03        
            set p-livestock-type log-normal 0.07 0.06         
            set p-wildfood-type log-normal 0.04 0.03         
            set p-firewood-type log-normal 0.11 0.02        
            set p-ganyu-type log-normal 0.11 0.07           
            set p-sell-type log-normal 0.05 0.04           
            set p-buy-type log-normal 0.37 0.25 
            
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.04 0.03              
            set p-spotato-type log-normal 0.02 0.02         
            set p-rice-type log-normal 0.05 0.05             
            set p-ppea-type log-normal 0.03 0.05            
            set p-tobacco-type log-normal 0.01 0.02          
            set p-cassava-type log-normal 0.06 0.03         
            set p-fishing-type log-normal 0.03 0.03         
            set p-hunting-type log-normal 0.04 0.03        
            set p-livestock-type log-normal 0.06 0.03       
            set p-wildfood-type log-normal 0.03 0.03       
            set p-firewood-type log-normal 0.09 0.02       
            set p-ganyu-type log-normal 0.16 0.13            
            set p-sell-type log-normal 0.06 0.05            
            set p-buy-type log-normal 0.30 0.24 
            
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.06 0.04             
            set p-spotato-type log-normal 0.02 0.03          
            set p-rice-type log-normal 0.04 0.04           
            set p-ppea-type log-normal 0.02 0.03            
            set p-tobacco-type log-normal 0.01 0.02          
            set p-cassava-type log-normal 0.05 0.01          
            set p-fishing-type log-normal 0.07 0.08         
            set p-hunting-type log-normal 0.05 0.03        
            set p-livestock-type log-normal 0.06 0.06       
            set p-wildfood-type log-normal 0.03 0.02      
            set p-firewood-type log-normal 0.07 0.01       
            set p-ganyu-type log-normal 0.09 0.08           
            set p-sell-type log-normal 0.08 0.05             
            set p-buy-type log-normal 0.35 0.30 
           
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.08 0.05              
            set p-spotato-type log-normal 0.02 0.02         
            set p-rice-type log-normal 0.03 0.03            
            set p-ppea-type log-normal 0.02 0.02            
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.05 0.02         
            set p-fishing-type log-normal 0.08 0.09        
            set p-hunting-type log-normal 0.04 0.03         
            set p-livestock-type log-normal 0.07 0.06         
            set p-wildfood-type log-normal 0.03 0.01        
            set p-firewood-type log-normal 0.05 0.03       
            set p-ganyu-type log-normal 0.10 0.08          
            set p-sell-type log-normal 0.07 0.05             
            set p-buy-type log-normal 0.31 0.23 
            
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.11 0.04           
            set p-spotato-type log-normal 0.01 0.02        
            set p-rice-type log-normal 0.03 0.03           
            set p-ppea-type log-normal 0.00 0.00          
            set p-tobacco-type log-normal 0.01 0.02          
            set p-cassava-type log-normal 0.05 0.02        
            set p-fishing-type log-normal 0.11 0.07        
            set p-hunting-type log-normal 0.06 0.02       
            set p-livestock-type log-normal 0.07 0.06        
            set p-wildfood-type log-normal 0.06 0.04       
            set p-firewood-type log-normal 0.07 0.02        
            set p-ganyu-type log-normal 0.10 0.06         
            set p-sell-type log-normal 0.07 0.03          
            set p-buy-type log-normal 0.23 0.14 
           
          ] 
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.11 0.05            
            set p-spotato-type log-normal 0.03 0.04          
            set p-rice-type log-normal 0.06 0.04            
            set p-ppea-type log-normal 0.04 0.03            
            set p-tobacco-type log-normal 0.01 0.02         
            set p-cassava-type log-normal 0.06 0.02          
            set p-fishing-type log-normal 0.11 0.06          
            set p-hunting-type log-normal 0.03 0.01          
            set p-livestock-type log-normal 0.09 0.02         
            set p-wildfood-type log-normal 0.08 0.02          
            set p-firewood-type log-normal 0.06 0.02        
            set p-ganyu-type log-normal 0.06 0.01           
            set p-sell-type log-normal  0.06 0.03             
            set p-buy-type log-normal 0.17 0.16 
            
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.14 0.04               
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.06 0.04           
            set p-ppea-type log-normal 0.03 0.04            
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.08 0.02         
            set p-fishing-type log-normal 0.08 0.06         
            set p-hunting-type log-normal 0.02 0.02        
            set p-livestock-type log-normal 0.10 0.02        
            set p-wildfood-type log-normal  0.07 0.03      
            set p-firewood-type log-normal 0.08 0.05       
            set p-ganyu-type log-normal  0.08 0.01         
            set p-sell-type log-normal  0.08 0.02          
            set p-buy-type log-normal 0.13 0.10 
            
          ] 
        ]
        if agent-type = 2     ; Poor male HH 
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.08 0.05               
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.06 0.07          
            set p-ppea-type log-normal 0.01 0.01           
            set p-tobacco-type log-normal 0.06 0.06          
            set p-cassava-type log-normal 0.07 0.01        
            set p-fishing-type log-normal 0.03 0.02         
            set p-hunting-type log-normal 0.04 0.02        
            set p-livestock-type log-normal  0.05 0.03        
            set p-wildfood-type log-normal 0.06 0.04         
            set p-firewood-type log-normal 0.06 0.02       
            set p-ganyu-type log-normal 0.05 0.03       
            set p-sell-type log-normal  0.07 0.04           
            set p-buy-type log-normal 0.32 0.22 
            
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.05 0.02            
            set p-spotato-type log-normal 0.02 0.02        
            set p-rice-type log-normal 0.04 0.03          
            set p-ppea-type log-normal 0.02 0.01            
            set p-tobacco-type log-normal  0.04 0.03          
            set p-cassava-type log-normal 0.06 0.01         
            set p-fishing-type log-normal 0.06 0.04        
            set p-hunting-type log-normal 0.03 0.02         
            set p-livestock-type log-normal 0.05 0.02          
            set p-wildfood-type log-normal 0.07 0.01        
            set p-firewood-type log-normal 0.08 0.03       
            set p-ganyu-type log-normal 0.08 0.03           
            set p-sell-type log-normal 0.05 0.03            
            set p-buy-type log-normal 0.33 0.18 
            
          ] 
         
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.06 0.04             
            set p-spotato-type log-normal 0.02 0.02       
            set p-rice-type log-normal 0.04 0.03         
            set p-ppea-type log-normal 0.02 0.02           
            set p-tobacco-type log-normal 0.04 0.03         
            set p-cassava-type log-normal 0.07 0.03        
            set p-fishing-type log-normal 0.05 0.03     
            set p-hunting-type log-normal 0.03 0.02       
            set p-livestock-type log-normal 0.06 0.03       
            set p-wildfood-type log-normal 0.05 0.04       
            set p-firewood-type log-normal 0.09 0.03       
            set p-ganyu-type log-normal 0.05 0.03            
            set p-sell-type log-normal 0.09 0.10              
            set p-buy-type log-normal 0.31 0.15 
            
          ]
           if month = "APRIL"
          [ 
            set p-maize-type log-normal 0.06 0.03              
            set p-spotato-type log-normal 0.03 0.02         
            set p-rice-type log-normal 0.05 0.03      
            set p-ppea-type log-normal  0.01 0.01           
            set p-tobacco-type log-normal 0.03 0.02        
            set p-cassava-type log-normal 0.08 0.01         
            set p-fishing-type log-normal 0.05 0.03        
            set p-hunting-type log-normal 0.02 0.01           
            set p-livestock-type log-normal 0.07 0.03       
            set p-wildfood-type log-normal 0.06 0.02       
            set p-firewood-type log-normal 0.09 0.02     
            set p-ganyu-type log-normal 0.05 0.04         
            set p-sell-type log-normal 0.12 0.10            
            set p-buy-type log-normal 0.26 0.20 
             
          ]  
          if month = "MAY"  
          [ 
            set p-maize-type log-normal 0.05 0.03              
            set p-spotato-type log-normal 0.05 0.03         
            set p-rice-type log-normal 0.06 0.04         
            set p-ppea-type log-normal 0.02 0.01           
            set p-tobacco-type log-normal 0.03 0.02          
            set p-cassava-type log-normal 0.07 0.02          
            set p-fishing-type log-normal 0.04 0.03         
            set p-hunting-type log-normal 0.03 0.01         
            set p-livestock-type log-normal 0.06 0.03         
            set p-wildfood-type log-normal 0.04 0.03         
            set p-firewood-type log-normal 0.10 0.06       
            set p-ganyu-type log-normal 0.08 0.05      
            set p-sell-type log-normal 0.15 0.13         
            set p-buy-type log-normal 0.21 0.12 
            
          ] 
          if month = "JUNE"
          [
            set p-maize-type log-normal 0.05 0.02              
            set p-spotato-type log-normal 0.02 0.02          
            set p-rice-type log-normal 0.05 0.04          
            set p-ppea-type log-normal 0.03 0.03           
            set p-tobacco-type log-normal 0.02 0.02           
            set p-cassava-type log-normal 0.07 0.01        
            set p-fishing-type log-normal 0.03 0.02        
            set p-hunting-type log-normal 0.04 0.02         
            set p-livestock-type log-normal 0.07 0.03         
            set p-wildfood-type log-normal 0.04 0.02         
            set p-firewood-type log-normal 0.10 0.03       
            set p-ganyu-type log-normal 0.08 0.05        
            set p-sell-type log-normal 0.14 0.06           
            set p-buy-type log-normal 0.24 0.12 
            
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.05 0.03             
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.04 0.04           
            set p-ppea-type log-normal 0.04 0.04             
            set p-tobacco-type log-normal 0.01 0.01         
            set p-cassava-type log-normal 0.05 0.02        
            set p-fishing-type log-normal 0.04 0.02         
            set p-hunting-type log-normal 0.03 0.02         
            set p-livestock-type log-normal 0.08 0.02          
            set p-wildfood-type log-normal 0.03 0.01         
            set p-firewood-type log-normal 0.08 0.02          
            set p-ganyu-type log-normal 0.06 0.04           
            set p-sell-type log-normal 0.12 0.08            
            set p-buy-type log-normal 0.33 0.24 
             
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.06 0.04              
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.04 0.03          
            set p-ppea-type log-normal 0.01 0.01           
            set p-tobacco-type log-normal 0.05 0.06           
            set p-cassava-type log-normal 0.08 0.04          
            set p-fishing-type log-normal 0.05 0.03           
            set p-hunting-type log-normal 0.02 0.01         
            set p-livestock-type log-normal 0.08 0.04          
            set p-wildfood-type log-normal 0.02 0.01          
            set p-firewood-type log-normal 0.11 0.04       
            set p-ganyu-type log-normal 0.05 0.04        
            set p-sell-type log-normal 0.08 0.04          
            set p-buy-type log-normal 0.30 0.22 
            
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.05 0.03             
            set p-spotato-type log-normal 0.01 0.01         
            set p-rice-type log-normal 0.04 0.03           
            set p-ppea-type log-normal 0.01 0.01           
            set p-tobacco-type log-normal 0.05 0.06         
            set p-cassava-type log-normal 0.08 0.05       
            set p-fishing-type log-normal 0.06 0.04         
            set p-hunting-type log-normal 0.03 0.02         
            set p-livestock-type log-normal 0.07 0.04         
            set p-wildfood-type log-normal 0.02 0.01         
            set p-firewood-type log-normal 0.10 0.02        
            set p-ganyu-type log-normal 0.05 0.03            
            set p-sell-type log-normal 0.06 0.04              
            set p-buy-type log-normal 0.34 0.25 
            
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.08 0.05              
            set p-spotato-type log-normal 0.01 0.01        
            set p-rice-type log-normal 0.04 0.03             
            set p-ppea-type log-normal 0.01 0.01              
            set p-tobacco-type log-normal 0.04 0.04         
            set p-cassava-type log-normal 0.07 0.02         
            set p-fishing-type log-normal 0.08 0.04        
            set p-hunting-type log-normal 0.04 0.03        
            set p-livestock-type log-normal 0.08 0.05         
            set p-wildfood-type log-normal 0.06 0.04        
            set p-firewood-type log-normal 0.10 0.02       
            set p-ganyu-type log-normal 0.07 0.04           
            set p-sell-type log-normal 0.06 0.02            
            set p-buy-type log-normal 0.24 0.09 
            
          ] 
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.12 0.06               
            set p-spotato-type log-normal 0.05 0.05         
            set p-rice-type log-normal 0.05 0.05           
            set p-ppea-type log-normal 0.02 0.02             
            set p-tobacco-type log-normal  0.06 0.04          
            set p-cassava-type log-normal 0.06 0.02          
            set p-fishing-type log-normal 0.06 0.04          
            set p-hunting-type log-normal 0.03 0.02         
            set p-livestock-type log-normal 0.07 0.02        
            set p-wildfood-type log-normal 0.05 0.02        
            set p-firewood-type log-normal 0.08 0.01        
            set p-ganyu-type log-normal 0.06 0.04            
            set p-sell-type log-normal 0.05 0.02            
            set p-buy-type log-normal 0.22 0.19 
           
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.11 0.07             
            set p-spotato-type log-normal 0.04 0.04         
            set p-rice-type log-normal 0.05 0.04          
            set p-ppea-type log-normal  0.04 0.03           
            set p-tobacco-type log-normal 0.06 0.04          
            set p-cassava-type log-normal 0.05 0.02         
            set p-fishing-type log-normal 0.08 0.03          
            set p-hunting-type log-normal 0.04 0.03         
            set p-livestock-type log-normal 0.07 0.01          
            set p-wildfood-type log-normal 0.06 0.01          
            set p-firewood-type log-normal 0.07 0.03         
            set p-ganyu-type log-normal 0.06 0.02          
            set p-sell-type log-normal 0.06 0.03              
            set p-buy-type log-normal 0.18 0.14 
          ]
          ]
           if agent-type = 3     ; Rich female HH 
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.07 0.03               
            set p-spotato-type log-normal 0.02 0.01        
            set p-rice-type log-normal 0.04 0.03          
            set p-ppea-type log-normal 0.02 0.01          
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.06 0.03        
            set p-fishing-type log-normal 0.03 0.01         
            set p-hunting-type log-normal 0.01 0.01         
            set p-livestock-type log-normal 0.07 0.02         
            set p-wildfood-type log-normal 0.07 0.05         
            set p-firewood-type log-normal 0.09 0.03        
            set p-ganyu-type log-normal 0.05 0.03       
            set p-sell-type log-normal 0.04 0.03             
            set p-buy-type log-normal 0.43 0.15 
          
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.05 0.03            
            set p-spotato-type log-normal 0.03 0.02       
            set p-rice-type log-normal 0.03 0.03         
            set p-ppea-type log-normal 0.02 0.01            
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.05 0.03         
            set p-fishing-type log-normal 0.04 0.02        
            set p-hunting-type log-normal 0.02 0.01         
            set p-livestock-type log-normal 0.07 0.03          
            set p-wildfood-type log-normal 0.05 0.04        
            set p-firewood-type log-normal 0.10 0.02      
            set p-ganyu-type log-normal 0.07 0.05           
            set p-sell-type log-normal  0.03 0.01           
            set p-buy-type log-normal 0.42 0.05 
            
          ] 
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.05 0.00               
            set p-spotato-type log-normal 0.03 0.02          
            set p-rice-type log-normal 0.04 0.04       
            set p-ppea-type log-normal 0.02 0.02            
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.05 0.03        
            set p-fishing-type log-normal 0.07 0.04          
            set p-hunting-type log-normal 0.03 0.02           
            set p-livestock-type log-normal 0.09 0.04        
            set p-wildfood-type log-normal 0.05 0.01        
            set p-firewood-type log-normal 0.11 0.02       
            set p-ganyu-type log-normal 0.06 0.02        
            set p-sell-type log-normal 0.03 0.01            
            set p-buy-type log-normal 0.34 0.05 
            
          ] 
          if month = "APRIL"  
          [ 
            set p-maize-type log-normal 0.06 0.02               
            set p-spotato-type log-normal 0.04 0.03         
            set p-rice-type log-normal 0.04 0.03          
            set p-ppea-type log-normal 0.02 0.02           
            set p-tobacco-type log-normal 0.02 0.03         
            set p-cassava-type log-normal 0.04 0.02           
            set p-fishing-type log-normal 0.05 0.04         
            set p-hunting-type log-normal 0.02 0.01         
            set p-livestock-type log-normal 0.10 0.05        
            set p-wildfood-type log-normal 0.05 0.04        
            set p-firewood-type log-normal 0.10 0.02       
            set p-ganyu-type log-normal 0.06 0.02        
            set p-sell-type log-normal 0.03 0.02          
            set p-buy-type log-normal 0.35 0.16 
            
          ] 
          if month = "MAY"
          [ 
            set p-maize-type log-normal 0.07 0.02              
            set p-spotato-type log-normal 0.03 0.04        
            set p-rice-type log-normal 0.03 0.03         
            set p-ppea-type log-normal 0.03 0.03            
            set p-tobacco-type log-normal 0.02 0.03          
            set p-cassava-type log-normal 0.05 0.03         
            set p-fishing-type log-normal 0.04 0.02      
            set p-hunting-type log-normal 0.03 0.02      
            set p-livestock-type log-normal 0.09 0.05        
            set p-wildfood-type log-normal 0.03 0.02       
            set p-firewood-type log-normal 0.12 0.02         
            set p-ganyu-type log-normal 0.06 0.02             
            set p-sell-type log-normal 0.05 0.03             
            set p-buy-type log-normal 0.34 0.19 
             
          ] 
          
          if month = "JUNE"
          [
            set p-maize-type log-normal 0.06 0.03             
            set p-spotato-type log-normal 0.03 0.04          
            set p-rice-type log-normal 0.05 0.04           
            set p-ppea-type log-normal 0.04 0.03            
            set p-tobacco-type log-normal 0.02 0.03           
            set p-cassava-type log-normal 0.05 0.03         
            set p-fishing-type log-normal 0.03 0.02          
            set p-hunting-type log-normal 0.01 0.01         
            set p-livestock-type log-normal 0.09 0.03          
            set p-wildfood-type log-normal 0.03 0.01          
            set p-firewood-type log-normal 0.14 0.03       
            set p-ganyu-type log-normal 0.05 0.03       
            set p-sell-type log-normal 0.07 0.04            
            set p-buy-type log-normal 0.32 0.20 
             
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.07 0.03             
            set p-spotato-type log-normal 0.03 0.04         
            set p-rice-type log-normal 0.05 0.03           
            set p-ppea-type log-normal 0.03 0.03            
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.05 0.02        
            set p-fishing-type log-normal 0.03 0.01        
            set p-hunting-type log-normal 0.01 0.01        
            set p-livestock-type log-normal 0.13 0.08         
            set p-wildfood-type log-normal 0.03 0.01         
            set p-firewood-type log-normal 0.14 0.04         
            set p-ganyu-type log-normal 0.06 0.03          
            set p-sell-type log-normal 0.09 0.06          
            set p-buy-type log-normal 0.28 0.22 
          
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.08 0.04              
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.03 0.03          
            set p-ppea-type log-normal 0.03 0.02           
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.05 0.02           
            set p-fishing-type log-normal 0.05 0.01            
            set p-hunting-type log-normal 0.03 0.02          
            set p-livestock-type log-normal 0.09 0.06         
            set p-wildfood-type log-normal 0.03 0.02         
            set p-firewood-type log-normal 0.13 0.03       
            set p-ganyu-type log-normal 0.06 0.02        
            set p-sell-type log-normal 0.08 0.07          
            set p-buy-type log-normal 0.27 0.04 
           
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.08 0.04              
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.03 0.02           
            set p-ppea-type log-normal 0.01 0.01           
            set p-tobacco-type log-normal 0.01 0.02        
            set p-cassava-type log-normal 0.05 0.04        
            set p-fishing-type log-normal 0.06 0.01          
            set p-hunting-type log-normal 0.03 0.01         
            set p-livestock-type log-normal 0.11 0.04         
            set p-wildfood-type log-normal 0.03 0.01         
            set p-firewood-type log-normal 0.12 0.02        
            set p-ganyu-type log-normal 0.07 0.03           
            set p-sell-type log-normal 0.10 0.04              
            set p-buy-type log-normal 0.26 0.09 
           
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.11 0.04             
            set p-spotato-type log-normal 0.02 0.01        
            set p-rice-type log-normal 0.03 0.02             
            set p-ppea-type log-normal 0.01 0.01             
            set p-tobacco-type log-normal 0.01 0.03         
            set p-cassava-type log-normal 0.07 0.03         
            set p-fishing-type log-normal 0.07 0.03        
            set p-hunting-type log-normal 0.02 0.02        
            set p-livestock-type log-normal 0.09 0.03         
            set p-wildfood-type log-normal 0.07 0.04         
            set p-firewood-type log-normal 0.12 0.04       
            set p-ganyu-type log-normal 0.08 0.03            
            set p-sell-type log-normal 0.04 0.02            
            set p-buy-type log-normal 0.23 0.11 
           
          ]  
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.16 0.02              
            set p-spotato-type log-normal 0.03 0.02         
            set p-rice-type log-normal 0.06 0.05          
            set p-ppea-type log-normal 0.03 0.01             
            set p-tobacco-type log-normal 0.01 0.03         
            set p-cassava-type log-normal 0.06 0.03           
            set p-fishing-type log-normal 0.08 0.02          
            set p-hunting-type log-normal 0.03 0.01         
            set p-livestock-type log-normal 0.09 0.05        
            set p-wildfood-type log-normal 0.08 0.03         
            set p-firewood-type log-normal 0.08 0.04       
            set p-ganyu-type log-normal 0.08 0.01             
            set p-sell-type log-normal 0.04 0.04             
            set p-buy-type log-normal 0.13 0.09
            
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.16 0.02             
            set p-spotato-type log-normal 0.03 0.03          
            set p-rice-type log-normal 0.08 0.07           
            set p-ppea-type log-normal 0.03 0.01             
            set p-tobacco-type log-normal 0.01 0.02          
            set p-cassava-type log-normal 0.05 0.03           
            set p-fishing-type log-normal 0.09 0.02         
            set p-hunting-type log-normal 0.03 0.02         
            set p-livestock-type log-normal 0.09 0.04          
            set p-wildfood-type log-normal 0.07 0.02         
            set p-firewood-type log-normal 0.07 0.02        
            set p-ganyu-type log-normal 0.10 0.03           
            set p-sell-type log-normal 0.03 0.01               
            set p-buy-type log-normal 0.10 0.07 
             
          ]  
        ]
        if agent-type = 4       ; poor female HH
        [ 
          if month = "JANUARY"     
          [ 
            set p-maize-type log-normal 0.05 0.03               
            set p-spotato-type log-normal 0.02 0.01         
            set p-rice-type log-normal 0.04 0.04      
            set p-ppea-type log-normal 0.02 0.01          
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.04 0.04         
            set p-fishing-type log-normal 0.05 0.03         
            set p-hunting-type log-normal 0.03 0.04          
            set p-livestock-type log-normal 0.10 0.06         
            set p-wildfood-type log-normal 0.08 0.03          
            set p-firewood-type log-normal 0.13 0.06        
            set p-ganyu-type log-normal 0.09 0.05           
            set p-sell-type log-normal 0.06 0.02             
            set p-buy-type log-normal 0.26 0.13 
            
          ] 
          if month = "FEBRUARY"
          [ 
            set p-maize-type log-normal 0.05 0.03           
            set p-spotato-type log-normal 0.02 0.01         
            set p-rice-type log-normal  0.03 0.05         
            set p-ppea-type log-normal 0.01 0.01           
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.05 0.05         
            set p-fishing-type log-normal 0.04 0.02           
            set p-hunting-type log-normal 0.03 0.04          
            set p-livestock-type log-normal 0.10 0.04        
            set p-wildfood-type log-normal 0.08 0.03         
            set p-firewood-type log-normal 0.15 0.05         
            set p-ganyu-type log-normal 0.08 0.03           
            set p-sell-type log-normal 0.07 0.03             
            set p-buy-type log-normal 0.26 0.09 
           
          ] 
          if month = "MARCH"
          [ 
            set p-maize-type log-normal 0.05 0.03              
            set p-spotato-type log-normal 0.03 0.02         
            set p-rice-type log-normal 0.03 0.05           
            set p-ppea-type log-normal 0.01 0.01             
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.06 0.05            
            set p-fishing-type log-normal 0.05 0.03         
            set p-hunting-type log-normal 0.02 0.04         
            set p-livestock-type log-normal 0.10 0.04       
            set p-wildfood-type log-normal 0.09 0.06         
            set p-firewood-type log-normal 0.17 0.07        
            set p-ganyu-type log-normal 0.07 0.02            
            set p-sell-type log-normal 0.06 0.01             
            set p-buy-type log-normal 0.22 0.08 
           
          ] 
          if month = "APRIL"
          [ 
            set p-maize-type log-normal 0.05 0.03              
            set p-spotato-type log-normal 0.02 0.02          
            set p-rice-type log-normal 0.03 0.03           
            set p-ppea-type log-normal 0.01 0.01            
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.05 0.05           
            set p-fishing-type log-normal 0.04 0.02           
            set p-hunting-type log-normal 0.03 0.04         
            set p-livestock-type log-normal 0.10 0.05         
            set p-wildfood-type log-normal 0.08 0.04           
            set p-firewood-type log-normal 0.14 0.06         
            set p-ganyu-type log-normal 0.07 0.02           
            set p-sell-type log-normal 0.06 0.02              
            set p-buy-type log-normal 0.29 0.11 
            
          ] 
          if month = "MAY"  
          [ 
            set p-maize-type log-normal 0.04 0.03             
            set p-spotato-type log-normal 0.02 0.02         
            set p-rice-type log-normal 0.03 0.03           
            set p-ppea-type log-normal 0.01 0.01             
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.05 0.04          
            set p-fishing-type log-normal 0.05 0.03        
            set p-hunting-type log-normal 0.03 0.04         
            set p-livestock-type log-normal 0.10 0.04          
            set p-wildfood-type log-normal 0.09 0.06          
            set p-firewood-type log-normal 0.14 0.05       
            set p-ganyu-type log-normal 0.07 0.03         
            set p-sell-type log-normal 0.06 0.02             
            set p-buy-type log-normal  0.28 0.12 
           
          ] 
          if month = "JUNE"
          [ 
            set p-maize-type log-normal 0.04 0.02           
            set p-spotato-type log-normal 0.02 0.02         
            set p-rice-type log-normal 0.02 0.03           
            set p-ppea-type log-normal 0.01 0.01            
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.04 0.03          
            set p-fishing-type log-normal 0.04 0.02          
            set p-hunting-type log-normal 0.03 0.04         
            set p-livestock-type log-normal 0.09 0.05         
            set p-wildfood-type log-normal 0.06 0.03       
            set p-firewood-type log-normal 0.15 0.05     
            set p-ganyu-type log-normal 0.08 0.03           
            set p-sell-type log-normal  0.05 0.03           
            set p-buy-type log-normal 0.35 0.07 
          
          ] 
          if month = "JULY"
          [ 
            set p-maize-type log-normal 0.03 0.02              
            set p-spotato-type log-normal 0.02 0.01         
            set p-rice-type log-normal 0.03 0.03         
            set p-ppea-type log-normal 0.01 0.02         
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.04 0.04          
            set p-fishing-type log-normal 0.04 0.02          
            set p-hunting-type log-normal 0.03 0.04          
            set p-livestock-type log-normal 0.10 0.05         
            set p-wildfood-type log-normal 0.04 0.03       
            set p-firewood-type log-normal 0.17 0.06       
            set p-ganyu-type log-normal 0.08 0.04         
            set p-sell-type log-normal 0.05 0.02         
            set p-buy-type log-normal 0.32 0.05 
            
          ] 
          if month = "AUGUST" 
          [ 
            set p-maize-type log-normal 0.03 0.02             
            set p-spotato-type log-normal 0.02 0.01         
            set p-rice-type log-normal 0.02 0.02         
            set p-ppea-type log-normal 0.00 0.01          
            set p-tobacco-type log-normal 0.00 0.01         
            set p-cassava-type log-normal 0.04 0.04         
            set p-fishing-type log-normal 0.06 0.02         
            set p-hunting-type log-normal 0.03 0.03       
            set p-livestock-type log-normal 0.09 0.05       
            set p-wildfood-type log-normal 0.05 0.04       
            set p-firewood-type log-normal 0.19 0.09      
            set p-ganyu-type log-normal 0.08 0.04    
            set p-sell-type log-normal 0.05 0.02       
            set p-buy-type log-normal 0.32 0.05 
            
          ] 
          if month = "SEPTEMBER"
          [ 
            set p-maize-type log-normal 0.04 0.02            
            set p-spotato-type log-normal 0.02 0.01       
            set p-rice-type log-normal 0.03 0.02        
            set p-ppea-type log-normal 0.01 0.02              
            set p-tobacco-type log-normal 0.00 0.01           
            set p-cassava-type log-normal 0.03 0.04         
            set p-fishing-type log-normal 0.04 0.01         
            set p-hunting-type log-normal 0.05 0.06         
            set p-livestock-type log-normal 0.10 0.05         
            set p-wildfood-type log-normal 0.06 0.02        
            set p-firewood-type log-normal 0.16 0.05       
            set p-ganyu-type log-normal 0.08 0.04       
            set p-sell-type log-normal 0.05 0.04        
            set p-buy-type log-normal 0.33 0.09 
           
          ] 
          if month = "OCTOBER" 
          [ 
            set p-maize-type log-normal 0.06 0.03             
            set p-spotato-type log-normal 0.02 0.02        
            set p-rice-type log-normal 0.03 0.03            
            set p-ppea-type log-normal 0.01 0.03            
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.04 0.04          
            set p-fishing-type log-normal 0.02 0.01         
            set p-hunting-type log-normal 0.03 0.04        
            set p-livestock-type log-normal 0.08 0.04        
            set p-wildfood-type log-normal 0.07 0.02      
            set p-firewood-type log-normal 0.15 0.05      
            set p-ganyu-type log-normal 0.09 0.05      
            set p-sell-type log-normal 0.05 0.03      
            set p-buy-type log-normal 0.30 0.12 
            
          ] 
          if month = "NOVEMBER"
          [
            set p-maize-type log-normal 0.08 0.04           
            set p-spotato-type log-normal 0.02 0.03        
            set p-rice-type log-normal 0.04 0.04         
            set p-ppea-type log-normal 0.02 0.03         
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.05 0.04         
            set p-fishing-type log-normal 0.07 0.04         
            set p-hunting-type log-normal 0.03 0.04        
            set p-livestock-type log-normal 0.09 0.05        
            set p-wildfood-type log-normal 0.09 0.01         
            set p-firewood-type log-normal 0.14 0.04         
            set p-ganyu-type log-normal 0.11 0.06       
            set p-sell-type log-normal 0.05 0.03      
            set p-buy-type log-normal 0.17 0.13
            
          ] 
          if month = "DECEMBER"
          [ 
            set p-maize-type log-normal 0.09 0.04              
            set p-spotato-type log-normal 0.03 0.03         
            set p-rice-type log-normal 0.05 0.05           
            set p-ppea-type log-normal 0.02 0.03           
            set p-tobacco-type log-normal 0.00 0.01          
            set p-cassava-type log-normal 0.04 0.04          
            set p-fishing-type log-normal 0.06 0.02      
            set p-hunting-type log-normal 0.03 0.04       
            set p-livestock-type log-normal 0.09 0.04        
            set p-wildfood-type log-normal 0.08 0.01         
            set p-firewood-type log-normal 0.17 0.07        
            set p-ganyu-type log-normal 0.10 0.05         
            set p-sell-type log-normal 0.07 0.07          
            set p-buy-type log-normal 0.13 0.10 
           
          ] 
        ] 
      ] 
  ]
  
  end
          
;;;;;;;;;;;;;;;;;;;;;
; AGENTS' DECISIONS ;
;;;;;;;;;;;;;;;;;;;;;  

to exo-onset 
  ; The month the targetted input program (TIP) starts depends on the scenario. 
  
  if scenario = "Early"
  [ 
    ifelse (month = "AUGUST") or (month = "SEPTEMBER") or (month = "OCTOBER") or (month = "NOVEMBER") or (month = "DECEMBER") 
  [ set exo-access TRUE] 
  [ set exo-access FALSE] 
  ] 
  
  if scenario = "Typical" 
  [ 
    ifelse (month = "SEPTEMBER") or (month = "OCTOBER") or (month = "NOVEMBER") or (month = "DECEMBER") 
  [ set exo-access TRUE] 
  [ set exo-access FALSE] 
  ] 
  
  if scenario = "Late" 
  [ 
    ifelse (month = "DECEMBER") 
  [ set exo-access TRUE] 
  [ set exo-access FALSE] 
  ] 
end

to exo-impact
  ; calculate the impact of exogenous processes 
  ask agents 
  [ 
   
    set exo-random random-float 1 
    
    ifelse (P-EXO <= exo-random)
    [ set exo-access-agent FALSE ] 
    [set exo-access-agent TRUE ] 
    
    if (exo-access = TRUE) and (exo-access-agent = TRUE) 
    [ 
      set p-maize-type (p-maize-type * EXO-FACTOR-M) 
      set p-ppea-type (p-ppea-type * EXO-FACTOR-P)
    ] 
  ]
end 

to decision-agent-type 
  ; calculate time allocation based on options 
  ask agents
  [       
    set p-total-type (p-maize-type + p-spotato-type + p-rice-type + p-ppea-type + p-tobacco-type + p-cassava-type + 
      p-fishing-type +  p-hunting-type + p-livestock-type + p-wildfood-type + p-firewood-type +  p-ganyu-type + p-sell-type + p-buy-type)
    
    if p-total-type = 0.0 
    [ 
      set p-total-type 0.1                    ; prevents division by zero should all activities total 0 by chance 
    ] 
    
    set p-maize (p-maize-type / p-total-type)
    set p-spotato (p-spotato-type / p-total-type)
    set p-rice (p-rice-type / p-total-type)
    set p-ppea (p-ppea-type / p-total-type) 
    set p-tobacco (p-tobacco-type / p-total-type)
    set p-cassava (p-cassava-type / p-total-type) 
    set p-fishing (p-fishing-type / p-total-type)
    set p-hunting (p-hunting-type / p-total-type)
    set p-livestock (p-livestock-type / p-total-type) 
    set p-wildfood (p-wildfood-type / p-total-type)
    set p-firewood (p-firewood-type / p-total-type)
    set p-ganyu (p-ganyu-type / p-total-type)
    set p-sell (p-sell-type / p-total-type)
    set p-buy (p-buy-type / p-total-type) 
  ] 
end 

;;;;;;;;;;;;;;;;;;
; UPDATE AGENTS' ;
;;;;;;;;;;;;;;;;;;

to define-wealth 
  ; calculate wealth-rating 
  ask agents 
  [
    ifelse p-sell <= 0.0 
    [set agent-wealth-rating 0.0] 
    [set agent-wealth-rating (p-buy / p-sell)] 
  ] 
end 

to define-food-adequacy 
  ; calculate food adequacy 
  ask agents 
  [ 
    if (agent-food-adequacy < 3) and (drought = false) and (exo-access-agent = true) and (agent-wealth-rating <= 1)
    [ 
      set agent-food-adequacy agent-food-adequacy + 0.2 
    ]
    if (agent-food-adequacy >= 1) and (drought  = true) and (exo-access-agent = false) and (agent-wealth-rating > 1) 
    [ 
      set agent-food-adequacy agent-food-adequacy - 0.2
    ]
    
  ]
  end 
  
;;;;;;;;;;;;;;;
; UPDATE VIEW ;
;;;;;;;;;;;;;;;

to update-view 
  ; update each of the views 
  if VIEW = "agent-type"
  [view-agent-type]
  if VIEW = "wealth-rating"
  [view-wealth-rating]
  if VIEW = "food-adequacy"
  [view-food-adequacy]
end 
  
        
            
  
@#$#@#$#@
GRAPHICS-WINDOW
391
159
909
371
-1
-1
1.016
1
10
1
1
1
0
1
1
1
0
499
0
178
0
0
1
ticks
30.0

BUTTON
197
24
278
57
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
288
24
369
57
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
12
58
184
103
Scenario
Scenario
"Early" "Typical" "Late"
1

SLIDER
201
226
377
259
P-DROUGHT
P-DROUGHT
0
1
1
0.1
1
NIL
HORIZONTAL

SLIDER
12
118
184
151
EXO-FACTOR-M
EXO-FACTOR-M
1
2
1.5
0.1
1
NIL
HORIZONTAL

SLIDER
12
172
184
205
EXO-FACTOR-P
EXO-FACTOR-P
1
2.00
1.1
0.1
1
NIL
HORIZONTAL

TEXTBOX
13
25
163
43
Input Subsidies 
14
103.0
1

TEXTBOX
202
205
352
223
Drought 
14
103.0
1

TEXTBOX
201
63
351
81
Display 
14
103.0
1

BUTTON
199
170
378
203
Wealth Rating
view-wealth-rating
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
198
129
376
162
Agent Type
view-agent-type
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
197
89
376
122
Food Adequacy
view-food-adequacy
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
12
227
187
260
P-EXO
P-EXO
0.0
1.0
0.4
0.1
1
NIL
HORIZONTAL

PLOT
392
20
911
153
Average Wealth Rating (buy:sell)
Time in months 
Ration buy: sell
0.0
12.0
0.0
10.0
true
true
"" ""
PENS
"Type 1 " 1.0 0 -13345367 true "" "plot (mean [agent-wealth-rating] of agents with [agent-type = 1])"
"Type 2" 1.0 0 -5825686 true "" "plot (mean [agent-wealth-rating] of agents with [agent-type = 2])"
"Type 3" 1.0 0 -3889007 true "" "plot (mean [agent-wealth-rating] of agents with [agent-type = 3])"
"Type 4" 1.0 0 -612749 true "" "plot (mean [agent-wealth-rating] of agents with [agent-type = 4])"

PLOT
11
395
383
517
Average P-Maize 
 Time in months 
Proportion
0.0
12.0
0.0
0.5
true
true
"" ""
PENS
"Type 1 " 1.0 0 -13345367 true "" "plot (mean [p-maize] of agents with [agent-type = 1])"
"Type 2" 1.0 0 -5825686 true "" "plot(mean [p-maize] of agents with [agent-type = 2])"
"Type 3" 1.0 0 -3889007 true "" "plot(mean [p-maize] of agents with [agent-type = 3])"
"Type 4" 1.0 0 -612749 true "" "plot(mean [p-maize] of agents with [agent-type = 4])"

PLOT
11
269
246
389
Average P-Cassava
Time in months 
Proportion 
0.0
12.0
0.0
0.5
true
true
"" ""
PENS
"Type 1" 1.0 0 -13345367 true "" "plot (mean [p-cassava] of agents with [agent-type = 1])"
"Type 2" 1.0 0 -5825686 true "" "plot (mean [p-cassava] of agents with [agent-type = 2])"
"Type 3" 1.0 0 -3889007 true "" "plot (mean [p-cassava] of agents with [agent-type = 3])"
"Type 4 " 1.0 0 -612749 true "" "plot (mean [p-cassava] of agents with [agent-type = 4])"

PLOT
393
377
909
515
Average Food Adequacy 
Food Adeq. 
Time in months
0.0
12.0
0.0
3.0
true
true
"" ""
PENS
"Type 1" 1.0 0 -13345367 true "" "plot(mean [agent-food-adequacy] of agents with [agent-type = 1])"
"Type 2" 1.0 0 -5825686 true "" "plot(mean [agent-food-adequacy] of agents with [agent-type = 2])"
"Type 3" 1.0 0 -3889007 true "" "plot(mean [agent-food-adequacy] of agents with [agent-type = 3])"
"Type 4 " 1.0 0 -612749 true "" "plot(mean [agent-food-adequacy] of agents with [agent-type = 1])"

MONITOR
254
268
376
313
NIL
drought
17
1
11

@#$#@#$#@
## WHAT IS IT?

A model of seasonal smallholder decision making in response to drought. 

## HOW IT WORKS

The model contains 15808 agents, which represent households located within two Traditional Authorities of Southern Malawi. Four different agent types are recognised, separated by gender and wellbeing. The model tracks seasonal decisions of agents as they allocate their time between 14 household tasks. Decisions are affected by the occurrence of drought and access to input subsidies. At each time step the wealth rating (buy:sell ratio) and food-adequacy value of each agent is updated. Each time step corresponds to one month and the simulation is run for a total of 10 years.  

## HOW TO USE IT

1. Adjust the slider parameters or use the default settings. 
2. Press the setup button. 
3. Select a display option: Food adequacy, Agent Type or Wealth-rating. 
4. Press the go button to start the simulation 
5. Look at the output monitors and plots to watch the changes in average wealth-rating etc. 

Parameters: 
A) Relating to drought: 
P-Drought: The likelihood of a drought year.
B) Relating to input subisidies: 
Scenario: The timing of the input subsidy program, this can be 'typical', 'early', or 'late'.
P-EXO: The proportion of the population with access to input subsidies.
EXOFACTOR-M : The factor by which agents with access to input subsidies bias time towards maize farming. 
EXOFACTOR-P: The factor by which agents with access to input subsidies bias time towards pigeon pea farming.


## THINGS TO NOTICE

Note how the decisions of the different agent types differ in response to drought. As well as the seasonal fluctuations in wealth-rating. 

## THINGS TO TRY

Try adjusting the parameters under various settings. How sensitive is the model to the particular parameters? 

How does increasing the probabilty of drought affect the avearge wealth-rating of each of the agent types? How dependent are the agents upon the market? 

Try changing the input subsidy scenario - is there any benefit to an input subsidy program that starts earlier in the year? 

Adjust the value of P-EXO - how does access to inputs affect the proportion of time agents spend farming maize, on average? 

## EXTENDING THE MODEL

One possible adaptation of the model, would be to equate time spent on each of the activities to a number of ‘maize units’.  The model could then be implemented to explore ways by which agents can optimise their wealth in maize units, which would highlight behaviours that assist in the realisation of smallholder food security.  


## CREDITS AND REFERENCES

Created by Samantha Dobbie, 2013 as part of an MSc project for the Universtiy of Southampton, UK. 
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Baseline" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="121"/>
    <metric>mean [p-maize] of agents with [agent-type = 1]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 1]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 1]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 1]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 1]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 1]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 1]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 1]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 1]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 1]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 1]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 2]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 2]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 2]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 2]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 2]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 2]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 2]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 2]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 2]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 2]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 2]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 3]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 3]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 3]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 3]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 3]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 3]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 3]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 3]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 3]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 3]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 3]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 4]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 4]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 4]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 4]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 4]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 4]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 4]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 4]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 4]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 4]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 4]</metric>
    <enumeratedValueSet variable="Scenario">
      <value value="&quot;Typical&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="EXO-FACTOR-P">
      <value value="1.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-DROUGHT">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="EXO-FACTOR-M">
      <value value="1.16"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-EXO">
      <value value="0.47"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Input-Subsidies-Scenario" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="121"/>
    <metric>mean [p-maize] of agents with [agent-type = 1]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 1]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 1]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 1]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 1]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 1]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 1]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 1]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 1]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 1]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 1]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 2]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 2]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 2]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 2]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 2]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 2]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 2]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 2]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 2]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 2]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 2]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 3]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 3]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 3]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 3]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 3]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 3]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 3]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 3]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 3]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 3]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 3]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 4]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 4]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 4]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 4]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 4]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 4]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 4]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 4]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 4]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 4]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 4]</metric>
    <enumeratedValueSet variable="EXO-FACTOR-P">
      <value value="1.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-DROUGHT">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Scenario">
      <value value="&quot;Typical&quot;"/>
      <value value="&quot;Early&quot;"/>
      <value value="&quot;Late&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="EXO-FACTOR-M">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-EXO">
      <value value="0.47"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Input-Subsidies-Access" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="121"/>
    <metric>mean [p-maize] of agents with [agent-type = 1]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 1]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 1]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 1]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 1]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 1]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 1]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 1]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 1]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 1]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 1]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 2]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 2]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 2]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 2]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 2]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 2]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 2]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 2]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 2]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 2]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 2]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 3]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 3]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 3]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 3]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 3]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 3]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 3]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 3]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 3]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 3]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 3]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 4]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 4]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 4]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 4]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 4]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 4]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 4]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 4]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 4]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 4]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 4]</metric>
    <enumeratedValueSet variable="EXO-FACTOR-P">
      <value value="1.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-DROUGHT">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Scenario">
      <value value="&quot;Typical&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="EXO-FACTOR-M">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-EXO">
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Input-Subsidies- M" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="121"/>
    <metric>mean [p-maize] of agents with [agent-type = 1]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 1]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 1]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 1]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 1]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 1]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 1]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 1]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 1]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 1]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 1]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 2]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 2]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 2]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 2]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 2]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 2]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 2]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 2]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 2]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 2]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 2]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 3]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 3]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 3]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 3]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 3]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 3]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 3]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 3]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 3]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 3]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 3]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 4]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 4]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 4]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 4]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 4]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 4]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 4]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 4]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 4]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 4]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 4]</metric>
    <enumeratedValueSet variable="EXO-FACTOR-P">
      <value value="1.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-DROUGHT">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Scenario">
      <value value="&quot;Typical&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="EXO-FACTOR-M">
      <value value="1.8"/>
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-EXO">
      <value value="0.47"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Drought1" repetitions="50" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="121"/>
    <metric>mean [p-maize] of agents with [agent-type = 1]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 1]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 1]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 1]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 1]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 1]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 1]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 1]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 1]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 1]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 1]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 1]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 2]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 2]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 2]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 2]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 2]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 2]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 2]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 2]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 2]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 2]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 2]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 2]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 3]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 3]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 3]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 3]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 3]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 3]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 3]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 3]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 3]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 3]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 3]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 3]</metric>
    <metric>mean [p-maize] of agents with [agent-type = 4]</metric>
    <metric>mean [p-spotato] of agents with [agent-type = 4]</metric>
    <metric>mean [p-rice] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ppea] of agents with [agent-type = 4]</metric>
    <metric>mean [p-tobacco] of agents with [agent-type = 4]</metric>
    <metric>mean [p-cassava] of agents with [agent-type = 4]</metric>
    <metric>mean [p-fishing] of agents with [agent-type = 4]</metric>
    <metric>mean [p-hunting] of agents with [agent-type = 4]</metric>
    <metric>mean [p-livestock] of agents with [agent-type = 4]</metric>
    <metric>mean [p-wildfood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-firewood] of agents with [agent-type = 4]</metric>
    <metric>mean [p-ganyu] of agents with [agent-type = 4]</metric>
    <metric>mean [p-sell] of agents with [agent-type = 4]</metric>
    <metric>mean [p-buy] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-wealth-rating] of agents with [agent-type = 4]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 1]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 2]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 3]</metric>
    <metric>mean [agent-food-adequacy] of agents with [agent-type = 4]</metric>
    <enumeratedValueSet variable="P-EXO">
      <value value="0.47"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Scenario">
      <value value="&quot;Typical&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="EXO-FACTOR-M">
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="EXO-FACTOR-P">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="P-DROUGHT">
      <value value="0.8"/>
      <value value="1"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
